.. image:: https://raw.githubusercontent.com/cybiere/baboossh/master/logo.png

SSH spreading made easy for red teams in a hurry.


BabooSSH allows you, from a simple SSH connection to a compromised host, to quickly gather info on other SSH endpoints to pivot and compromise them.

Licence
+++++++

BabooSSH is developped by `Cybiere <https://twitter.com/Cybiere>`_ and `Akerva <https://akerva.com/>`_ and provided for free under the GNU/GPLv3 licence.

Install 
+++++++

It's as easy as a::

   pip install baboossh


Documentation
+++++++++++++

The documentation is under redaction and some things might be missing, but you can find it there: `<https://baboossh.cybiere.fr>`_ .


